"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.loadableLib = exports.loadableTimeout = exports.loadableDelay = exports.loadable = void 0;

var _component = _interopRequireDefault(require("@loadable/component"));

var _pMinDelay = _interopRequireDefault(require("p-min-delay"));

var _promiseTimeout = require("promise-timeout");

var _LoadSpinner = require("./LoadSpinner");

// https://www.smooth-code.com/open-source/loadable-components/

/**
 * 组件导入函数,支持自定义加载动画
 * @param {Function} func 返回动态引入的函数, 如 ()=>import('./a/b/c')
 * @param {Object} options {spinner:spinner, // loading动画组件, 默认为loadSpinner}
 * @returns {Component}
 */
var loadable = function loadable(func) {
  var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  return (0, _component.default)(func, {
    fallback: (0, _LoadSpinner.loadSpinner)(options.spinner)
  });
};
/**
 * 组件导入函数,支持延时加载
 * @param {Promise} promise 动态引入的返回值, 如 import('./a/b/c')
 * @param {Object} options {spinner:spinner, // loading动画组件, 默认为loadSpinner, delay:200, // 延迟时间, 默认200ms}
 * @returns {Component}
 */


exports.loadable = loadable;

var loadableDelay = function loadableDelay(promise) {
  var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {
    delay: 200
  };
  return (0, _component.default)(function () {
    return (0, _pMinDelay.default)(promise, options.delay);
  }, {
    fallback: (0, _LoadSpinner.loadSpinner)(options.spinner)
  });
};
/**
 * 组件导入函数,支持加载超时
 * @param {Promise} promise 动态引入的返回值, 如 import('./a/b/c')
 * @param {Object} options {spinner:spinner, // loading动画组件, 默认为loadSpinner, time:200, // 过期时间, 默认5000ms}
 * @returns {Component}
 */


exports.loadableDelay = loadableDelay;

var loadableTimeout = function loadableTimeout(promise) {
  var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {
    time: 5000
  };
  return (0, _component.default)(function () {
    return (0, _promiseTimeout.timeout)(promise, options.time);
  }, {
    fallback: (0, _LoadSpinner.loadSpinner)(options.spinner)
  });
};
/**
 * lib动态导入函数
 * @param {Function} func 返回动态引入的函数, 如 ()=>import('abc')
 */


exports.loadableTimeout = loadableTimeout;
var loadableLib = _component.default.lib;
exports.loadableLib = loadableLib;